summaryrefslogtreecommitdiff
path: root/spec/ruby/shared/file/world_writable.rb
diff options
context:
space:
mode:
Diffstat (limited to 'spec/ruby/shared/file/world_writable.rb')
-rw-r--r--spec/ruby/shared/file/world_writable.rb18
1 files changed, 9 insertions, 9 deletions
diff --git a/spec/ruby/shared/file/world_writable.rb b/spec/ruby/shared/file/world_writable.rb
index 61b691bcb6..fcff09636e 100644
--- a/spec/ruby/shared/file/world_writable.rb
+++ b/spec/ruby/shared/file/world_writable.rb
@@ -14,31 +14,31 @@ describe :file_world_writable, shared: true do
platform_is_not :windows do
it "returns nil if the file is chmod 600" do
File.chmod(0600, @file)
- @object.world_writable?(@file).should be_nil
+ @object.world_writable?(@file).should == nil
end
it "returns nil if the file is chmod 000" do
File.chmod(0000, @file)
- @object.world_writable?(@file).should be_nil
+ @object.world_writable?(@file).should == nil
end
it "returns nil if the file is chmod 700" do
File.chmod(0700, @file)
- @object.world_writable?(@file).should be_nil
+ @object.world_writable?(@file).should == nil
end
- # We don't specify what the Fixnum is because it's system dependent
- it "returns a Fixnum if the file is chmod 777" do
+ # We don't specify what the Integer is because it's system dependent
+ it "returns an Integer if the file is chmod 777" do
File.chmod(0777, @file)
- @object.world_writable?(@file).should be_an_instance_of(Fixnum)
+ @object.world_writable?(@file).should.instance_of?(Integer)
end
- it "returns a Fixnum if the file is a directory and chmod 777" do
- dir = rand().to_s + '-ww'
+ it "returns an Integer if the file is a directory and chmod 777" do
+ dir = tmp(rand().to_s + '-ww')
Dir.mkdir(dir)
Dir.should.exist?(dir)
File.chmod(0777, dir)
- @object.world_writable?(dir).should be_an_instance_of(Fixnum)
+ @object.world_writable?(dir).should.instance_of?(Integer)
Dir.rmdir(dir)
end
end